==> ipf-commons-ihe-fhir-r4-mhd-3.7.4-sources.jar: org/openehealth/ipf/commons/ihe/fhir/iti67/Iti67TransactionConfiguration.java <==
/*
 * Copyright 2016 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.openehealth.ipf.commons.ihe.fhir.iti67;

import ca.uhn.fhir.context.FhirVersionEnum;
import org.openehealth.ipf.commons.ihe.fhir.FhirTransactionConfiguration;
import org.openehealth.ipf.commons.ihe.fhir.FhirTransactionValidator;
import org.openehealth.ipf.commons.ihe.fhir.audit.FhirQueryAuditDataset;

/**
 * Standard Configuration for Iti67Component.  Supports lazy-loading by default.
 *
 * @author Christian Ohr
 * @since 3.6
 */
public class Iti67TransactionConfiguration extends FhirTransactionConfiguration<FhirQueryAuditDataset> {

    public Iti67TransactionConfiguration() {
        super("mhd-iti67",
                "Find Document References",
                true,
                new Iti67AuditStrategy(false),
                new Iti67AuditStrategy(true),
                FhirVersionEnum.R4,
                new Iti67ResourceProvider(),                    // Consumer side. accept registrations
                new Iti67ClientRequestFactory(),
                FhirTransactionValidator.NO_VALIDATION);
        setSupportsLazyLoading(true);
    }
}

==> ipf-commons-ihe-fhir-r4-mhd-4.8.0-sources.jar: org/openehealth/ipf/commons/ihe/fhir/iti67/Iti67TransactionConfiguration.java <==
/*
 * Copyright 2016 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.openehealth.ipf.commons.ihe.fhir.iti67;

import ca.uhn.fhir.context.FhirVersionEnum;
import org.openehealth.ipf.commons.ihe.fhir.FhirTransactionConfiguration;
import org.openehealth.ipf.commons.ihe.fhir.FhirTransactionValidator;
import org.openehealth.ipf.commons.ihe.fhir.audit.FhirQueryAuditDataset;

/**
 * Standard Configuration for Iti67Component.  Supports lazy-loading by default.
 *
 * @author Christian Ohr
 * @since 3.6
 */
public class Iti67TransactionConfiguration extends FhirTransactionConfiguration<FhirQueryAuditDataset> {

    public Iti67TransactionConfiguration() {
        super("mhd-iti67",
                "Find Document References",
                true,
                new Iti67AuditStrategy(false),
                new Iti67AuditStrategy(true),
                FhirVersionEnum.R4,
                new Iti67ResourceProvider(),
                new Iti67ClientRequestFactory(),
                FhirTransactionValidator.NO_VALIDATION);
        setSupportsLazyLoading(true);
    }
}
